aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSven Göthel <[email protected]>2024-01-22 06:38:05 +0100
committerSven Göthel <[email protected]>2024-01-22 06:38:05 +0100
commitdaf9ae20ebc45c851bc3b8384f4cee3cded8d9dc (patch)
tree43c2659fa9616452b610212eea89da81af33423d
parent5f9fb7159fa33bc979e5050d384b6939658049bd (diff)
Bug 1490: Add missing rename Shape.transformMvTo() -> applyMatToMv(), an transformMvTo() was an intermediate rename (oops)
-rw-r--r--src/graphui/classes/com/jogamp/graph/ui/Shape.java62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/graphui/classes/com/jogamp/graph/ui/Shape.java b/src/graphui/classes/com/jogamp/graph/ui/Shape.java
index 32d1402b0..3f399d1ae 100644
--- a/src/graphui/classes/com/jogamp/graph/ui/Shape.java
+++ b/src/graphui/classes/com/jogamp/graph/ui/Shape.java
@@ -745,7 +745,7 @@ public abstract class Shape {
/**
* Renders the shape.
* <p>
* {@link #transformMvTo(PMVMatrix4f)} is expected to be completed beforehand.
* </p>
* @param gl the current GL object
* @param renderer {@link RegionRenderer} which might be used for Graph Curve Rendering, also source of {@link RegionRenderer#getMatrix()} and {@link RegionRenderer#getViewport()}.
@@ -854,7 +854,7 @@ public abstract class Shape {
* @see #getMat()
* @see PMVMatrix4f#mulMv(Matrix4f)
*/
- public final void transformMvTo(final PMVMatrix4f pmv) {
+ public final void applyMatToMv(final PMVMatrix4f pmv) {
if( !iMatIdent ) {
pmv.mulMv(iMat);
}
@@ -868,7 +868,7 @@ public abstract class Shape {
* </p>
* @see #getMat(Matrix4f)
* @see #isMatIdentity()
- * @see #transformMvTo(PMVMatrix4f)
+ * @see #applyMatToMv(PMVMatrix4f)
* @see #updateMat()
*/
public final Matrix4f getMat() { iMatIdent = false; return iMat; }
@@ -877,7 +877,7 @@ public abstract class Shape {
* Returns a copy of the internal {@link Matrix4f} to {@code out} see {@link #updateMat()}.
* @see #getMat()
* @see #isMatIdentity()
- * @see #transformMvTo(PMVMatrix4f)
+ * @see #applyMatToMv(PMVMatrix4f)
* @see #updateMat()
*/
public final Matrix4f getMat(final Matrix4f out) { out.load(iMat); return out; }
@@ -911,7 +911,7 @@ public abstract class Shape {
* @see #getScale()
* @see #getRotation()
* @see #getRotationPivot()
- * @see #transformMvTo(PMVMatrix4f)
+ * @see #applyMatToMv(PMVMatrix4f)
*/
public final void updateMat() {
final boolean hasScale = !scale.isEqual(Vec3f.ONE);
@@ -955,33 +955,33 @@ public abstract class Shape {
/**
* {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) Setup} the given {@link PMVMatrix4f}
* and apply this shape's {@link #transformMvTo(PMVMatrix4f) transformation}.
* </p>
* @param pmvMatrixSetup {@link Scene.PMVMatrixSetup} to {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} given {@link PMVMatrix4f} {@code pmv}.
* @param viewport used viewport for {@link PMVMatrix4f#mapObjToWin(Vec3f, Recti, Vec3f)}
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @return the given {@link PMVMatrix4f} for chaining
* @see Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti)
- * @see #transformMvTo(PMVMatrix4f)
+ * @see #applyMatToMv(PMVMatrix4f)
* @see #setPMVMatrix(Scene, PMVMatrix4f)
*/
public final PMVMatrix4f setPMVMatrix(final Scene.PMVMatrixSetup pmvMatrixSetup, final Recti viewport, final PMVMatrix4f pmv) {
pmvMatrixSetup.set(pmv, viewport);
- transformMvTo(pmv);
+ applyMatToMv(pmv);
return pmv;
}
/**
* {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) Setup} the given {@link PMVMatrix4f}
* and apply this shape's {@link #transformMvTo(PMVMatrix4f) transformation}.
* </p>
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @return the given {@link PMVMatrix4f} for chaining
* @see Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti)
- * @see #transformMvTo(PMVMatrix4f)
+ * @see #applyMatToMv(PMVMatrix4f)
* @see #setPMVMatrix(com.jogamp.graph.ui.Scene.PMVMatrixSetup, Recti, PMVMatrix4f)
*/
public final PMVMatrix4f setPMVMatrix(final Scene scene, final PMVMatrix4f pmv) {
@@ -993,7 +993,7 @@ public abstract class Shape {
* <p>
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
* including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
* @param viewport the int[4] viewport
@@ -1024,7 +1024,7 @@ public abstract class Shape {
* <p>
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
* including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
* @param viewport the int[4] viewport
@@ -1055,12 +1055,12 @@ public abstract class Shape {
* Retrieve surface (view) size in pixels of this shape.
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param pmvMatrixSetup {@link Scene.PMVMatrixSetup} to {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} given {@link PMVMatrix4f} {@code pmv}.
* @param viewport used viewport for {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)}
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param surfaceSize int[2] target surface size
* @return given int[2] {@code surfaceSize} in pixels for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
* @see #getSurfaceSize(PMVMatrix4f, Recti, int[])
@@ -1074,11 +1074,11 @@ public abstract class Shape {
* Retrieve surface (view) size in pixels of this shape.
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param surfaceSize int[2] target surface size
* @return given int[2] {@code surfaceSize} in pixels for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
* @see #getSurfaceSize(PMVMatrix4f, Recti, int[])
@@ -1109,7 +1109,7 @@ public abstract class Shape {
* <p>
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
* including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
* @param viewport the int[4] viewport
@@ -1133,11 +1133,11 @@ public abstract class Shape {
* Retrieve pixel per scaled shape-coordinate unit, i.e. [px]/[obj].
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param pixPerShape float[2] pixel per scaled shape-coordinate unit result storage
* @return given float[2] {@code pixPerShape} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
* @see #getPixelPerShapeUnit(int[], float[])
@@ -1159,7 +1159,7 @@ public abstract class Shape {
* <p>
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
* including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
* @param viewport the viewport
@@ -1185,13 +1185,13 @@ public abstract class Shape {
* Map given object coordinate relative to this shape to window coordinates.
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param pmvMatrixSetup {@link Scene.PMVMatrixSetup} to {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} given {@link PMVMatrix4f} {@code pmv}.
* @param viewport used viewport for {@link PMVMatrix4f#mapObjToWin(Vec3f, Recti, Vec3f)}
* @param objPos object position relative to this shape's center
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param glWinPos int[2] target window position of objPos relative to this shape
* @return given int[2] {@code glWinPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
* @see #shapeToWinCoord(PMVMatrix4f, Recti, float[], int[])
@@ -1205,12 +1205,12 @@ public abstract class Shape {
* Map given object coordinate relative to this shape to window coordinates.
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param objPos object position relative to this shape's center
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param glWinPos int[2] target window position of objPos relative to this shape
* @return given int[2] {@code glWinPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
* @see #shapeToWinCoord(PMVMatrix4f, Recti, float[], int[])
@@ -1225,7 +1225,7 @@ public abstract class Shape {
* <p>
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
* including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
* @param viewport the Rect4i viewport
@@ -1254,14 +1254,14 @@ public abstract class Shape {
* Map given gl-window-coordinates to object coordinates relative to this shape and its z-coordinate.
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param pmvMatrixSetup {@link Scene.PMVMatrixSetup} to {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} given {@link PMVMatrix4f} {@code pmv}.
* @param viewport used viewport for {@link PMVMatrix4f#mapWinToObj(float, float, float, Recti, Vec3f)}
* @param glWinX in GL window coordinates, origin bottom-left
* @param glWinY in GL window coordinates, origin bottom-left
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param objPos target object position of glWinX/glWinY relative to this shape
* @return given {@code objPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)}
* and {@link Matrix4f#mapWinToObj(float, float, float, float, Matrix4f, Recti, Vec3f, Vec3f) gluUnProject(..)}
@@ -1277,13 +1277,13 @@ public abstract class Shape {
* Map given gl-window-coordinates to object coordinates relative to this shape and its z-coordinate.
* <p>
* The given {@link PMVMatrix4f} will be {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} properly for this shape
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}.
* </p>
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param glWinX in GL window coordinates, origin bottom-left
* @param glWinY in GL window coordinates, origin bottom-left
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
* {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param objPos target object position of glWinX/glWinY relative to this shape
* @return given {@code objPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)}
* and {@link Matrix4f#mapWinToObj(float, float, float, float, Matrix4f, Recti, Vec3f, Vec3f) gluUnProject(..)}
@@ -745,7 +745,7 @@ public abstract class Shape {
* Renders the shape.
* <p>
- * {@link #transformMvTo(PMVMatrix4f)} is expected to be completed beforehand.
+ * {@link #applyMatToMv(PMVMatrix4f)} is expected to be completed beforehand.
* </p>
* @param gl the current GL object
@@ -955,33 +955,33 @@ public abstract class Shape {
/**
* {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) Setup} the given {@link PMVMatrix4f}
- * and apply this shape's {@link #transformMvTo(PMVMatrix4f) transformation}.
+ * and apply this shape's {@link #applyMatToMv(PMVMatrix4f) transformation}.
* </p>
* @param pmvMatrixSetup {@link Scene.PMVMatrixSetup} to {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) setup} given {@link PMVMatrix4f} {@code pmv}.
@@ -955,33 +955,33 @@ public abstract class Shape {
* @param viewport used viewport for {@link PMVMatrix4f#mapObjToWin(Vec3f, Recti, Vec3f)}
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @return the given {@link PMVMatrix4f} for chaining
* @see Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti)
@@ -955,33 +955,33 @@ public abstract class Shape {
/**
* {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) Setup} the given {@link PMVMatrix4f}
- * and apply this shape's {@link #transformMvTo(PMVMatrix4f) transformation}.
+ * and apply this shape's {@link #applyMatToMv(PMVMatrix4f) transformation}.
* </p>
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
@@ -955,33 +955,33 @@ public abstract class Shape {
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @return the given {@link PMVMatrix4f} for chaining
* @see Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti)
@@ -993,7 +993,7 @@ public abstract class Shape {
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
@@ -1024,7 +1024,7 @@ public abstract class Shape {
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
@@ -1055,12 +1055,12 @@ public abstract class Shape {
* @param viewport used viewport for {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)}
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param surfaceSize int[2] target surface size
* @return given int[2] {@code surfaceSize} in pixels for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
@@ -1074,11 +1074,11 @@ public abstract class Shape {
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param surfaceSize int[2] target surface size
* @return given int[2] {@code surfaceSize} in pixels for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
@@ -1109,7 +1109,7 @@ public abstract class Shape {
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
@@ -1133,11 +1133,11 @@ public abstract class Shape {
* @param scene {@link Scene} to retrieve {@link Scene.PMVMatrixSetup} and the viewport.
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param pixPerShape float[2] pixel per scaled shape-coordinate unit result storage
* @return given float[2] {@code pixPerShape} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
@@ -1159,7 +1159,7 @@ public abstract class Shape {
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
@@ -1185,13 +1185,13 @@ public abstract class Shape {
* @param objPos object position relative to this shape's center
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param glWinPos int[2] target window position of objPos relative to this shape
* @return given int[2] {@code glWinPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
@@ -1205,12 +1205,12 @@ public abstract class Shape {
* @param objPos object position relative to this shape's center
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param glWinPos int[2] target window position of objPos relative to this shape
* @return given int[2] {@code glWinPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)} operation, otherwise {@code null}
@@ -1225,7 +1225,7 @@ public abstract class Shape {
* The given {@link PMVMatrix4f} has to be setup properly for this object,
* i.e. its {@link GLMatrixFunc#GL_PROJECTION} and {@link GLMatrixFunc#GL_MODELVIEW} for the surrounding scene
- * including this shape's {@link #transformMvTo(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
+ * including this shape's {@link #applyMatToMv(PMVMatrix4f)}. See {@link #setPMVMatrix(Scene, PMVMatrix4f)}.
* </p>
* @param pmv well formed {@link PMVMatrix4f}, e.g. could have been setup via {@link Shape#setPMVMatrix(Scene, PMVMatrix4f)}.
@@ -1254,14 +1254,14 @@ public abstract class Shape {
* @param glWinY in GL window coordinates, origin bottom-left
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param objPos target object position of glWinX/glWinY relative to this shape
* @return given {@code objPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)}
@@ -1277,13 +1277,13 @@ public abstract class Shape {
* @param glWinY in GL window coordinates, origin bottom-left
* @param pmv a new {@link PMVMatrix4f} which will {@link Scene.PMVMatrixSetup#set(PMVMatrix4f, Recti) be setup},
- * {@link #transformMvTo(PMVMatrix4f) shape-transformed} and can be reused by the caller.
+ * {@link #applyMatToMv(PMVMatrix4f) shape-transformed} and can be reused by the caller.
* @param objPos target object position of glWinX/glWinY relative to this shape
* @return given {@code objPos} for successful {@link Matrix4f#mapObjToWin(Vec3f, Matrix4f, Recti, Vec3f) gluProject(..)}